@@ -9,6 +9,7 @@ WGVmix <- function(y, id, w, v, pv = 300, eps = 1e-6, rtol = 1.0e-6, verb=0){
    # Output:
    #   v as above
    #   fv mixing density for the variances
+   #   g mixture density at the observed s's
    #   flag indicating (non)convergence code (0 is OK)
 
 m <- tapply(y,id,"length")
@@ -32,7 +33,8 @@ A <- (exp(-R) * R^r)/sgamma
 A <- Matrix(A, sparse = TRUE)
 f <- KWDual(s,wv,dv,A,rtol = rtol, verb = verb)
 y <- f$f/sum(f$f * dv)
-z <- list(x = v, y = y, logLik = f$logLik, flag = f$status)
+g <- A %*% y
+z <- list(x = v, y = y, g = g, logLik = f$logLik, flag = f$status)
 class(z) <- "density"
 return(z)
 }
